# libss
Independent-component-analysis-based blind audio source separation library.

## Installation
```
pip install libss
```

## Available algorithms
- [Auxiliary-function-based independent vector analysis (AuxIVA)](https://doi.org/10.1109/ASPAA.2011.6082320)

### Coming soon...
- [Online AuxIVA](https://doi.org/10.1109/HSCMA.2014.6843261)
- [Independent low-rank matrix analysis (ILRMA)](https://doi.org/10.1109/TASLP.2016.2577880)
- [Fast multichannel nonnegative matrix factorization (FastMNMF)](https://doi.org/10.23919/EUSIPCO.2019.8902557)

## Example
- [AuxIVA](examples/auxiva.py)
